@@ -3,7 +3,7 @@ package Module::Install::DSL;
 use strict;
 use vars qw{$VERSION $ISCORE};
 BEGIN {
-	$VERSION = '0.90';
+	$VERSION = '0.93';
 	$ISCORE  = 1;
 	*inc::Module::Install::DSL::VERSION = *VERSION;
 	@inc::Module::Install::DSL::ISA     = __PACKAGE__;
@@ -38,13 +38,15 @@ sub import {
 	}
 
 	# Convert the basic syntax to code
-	my $code = "package main;\n\n"
+	my $code = "INIT {\n"
+	         . "package main;\n\n"
 	         . dsl2code($dsl)
-	         . "\n\nWriteAll();\n";
+	         . "\n\nWriteAll();\n"
+	         . "}\n";
 
 	# Execute the script
 	eval $code;
-	print STDERR "Failed to execute the generated code" if $@;
+	print STDERR "Failed to execute the generated code...\n$@" if $@;
 
 	exit(0);
 }
